@@ -38,12 +38,14 @@ fn eject_test(
         .stderr(Stdio::null())
         .spawn()?
         .into();
+    let dummy_process_clone = dummy_process.try_clone().unwrap();
+    let _guard = dispose::defer(|| {
+        dummy_process_clone.kill().unwrap();
+    });
 
     let syringe = Syringe::new();
     let module = syringe.inject(&dummy_process, payload_path.as_ref())?;
     syringe.eject(module)?;
 
-    dummy_process.kill()?;
-
     Ok(())
 }
